
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <stdbool.h>
#include <unistd.h>

#define BUF_SZ 0x100

int64_t read_varint(void)
{
    // Remark: can make negative numbers as well.
    uint8_t buf;
    int64_t result = 0;
    size_t shift = 0;
    while (true)
    {
        if (read(0, &buf, 1) <= 0) goto fail;
        // printf("S=%d B=%02x\n", shift, buf);
        if (shift == 63)
        {
            if (buf > 1 || (buf & 0x80)) goto fail;
            result |= (uint64_t) buf << 63;
            return result;
        }
        result |= ((uint64_t) buf & 0x7f) << shift;
        if (buf < 0x80) return result;
        shift += 7;
    }

fail:
    _exit(1);
}

void read_full(int fd, char* buf, size_t len)
{
    while (len > 0)
    {
        ssize_t res = read(fd, buf, len);
        if (res <= 0) _exit(1);
        len -= res;
        buf += res;
    }
}

void
handle_raw(int64_t count)
{
    volatile size_t tmp;
    char buf[BUF_SZ] = {0};
    while (count != 0)
    {
        int64_t toread = BUF_SZ;
        if (count < BUF_SZ) toread = count;
        tmp = (uint16_t)toread;
        // printf("T=%#llx C=%#llx\n", toread, count);
        read_full(0, buf, (uint16_t)toread + 1);
        write(1, buf, tmp);
        count -= toread;
    }
}

void
handle_short(int64_t count)
{
    char buf;
    read_full(0, &buf, 1);
    while (count--) write(1, &buf, 1);
}

int
main()
{
    setbuf(stdin, NULL);
    setbuf(stdout, NULL);
    setbuf(stderr, NULL);

    while (true)
    {
        int64_t control = read_varint();
        if (control == 0) break;
        int64_t raw = control & 1;
        int64_t count = ((uint64_t)control) >> 1;
        // printf("%#llx %d\n", count, raw);
        if (raw) handle_raw(count);
        else handle_short(count);
    }
}
